@@ -42,6 +42,7 @@
 #include "LogFactory.h"
 #include "DownloadContext.h"
 #include "fmt.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
@@ -80,6 +81,18 @@ bool FillRequestGroupCommand::execute()
     }
   }
   e_->addRoutineCommand(std::unique_ptr<Command>(this));
+
+  // let's make sure we come back here every second or so
+  // if we use the optimize-concurrent-download option
+  if (rgman->getOptimizeConcurrentDownloads()) {
+    const auto& now = global::wallclock();
+    if (std::chrono::duration_cast<std::chrono::seconds>(
+            lastExecTime.difference(now)) >= 1_s) {
+      lastExecTime = now;
+      rgman->requestQueueCheck();
+    }
+  }
+
   return false;
 }
 
