@@ -108,6 +108,7 @@ const char KEY_BITFIELD[] = "bitfield";
 const char KEY_PIECE_LENGTH[] = "pieceLength";
 const char KEY_NUM_PIECES[] = "numPieces";
 const char KEY_FOLLOWED_BY[] = "followedBy";
+const char KEY_FOLLOWING[] = "following";
 const char KEY_BELONGS_TO[] = "belongsTo";
 const char KEY_INFO_HASH[] = "infoHash";
 const char KEY_NUM_SEEDERS[] = "numSeeders";
@@ -664,6 +665,11 @@ void gatherProgressCommon(Dict* entryDict,
       entryDict->put(KEY_FOLLOWED_BY, std::move(list));
     }
   }
+  if (requested_key(keys, KEY_FOLLOWING)) {
+    if (group->following()) {
+      entryDict->put(KEY_FOLLOWING, GroupId::toHex(group->following()));
+    }
+  }
   if (requested_key(keys, KEY_BELONGS_TO)) {
     if (group->belongsTo()) {
       entryDict->put(KEY_BELONGS_TO, GroupId::toHex(group->belongsTo()));
@@ -824,6 +830,11 @@ void gatherStoppedDownload(Dict* entryDict,
       entryDict->put(KEY_FOLLOWED_BY, std::move(list));
     }
   }
+  if (requested_key(keys, KEY_FOLLOWING)) {
+    if (ds->following) {
+      entryDict->put(KEY_FOLLOWING, GroupId::toHex(ds->following));
+    }
+  }
   if (requested_key(keys, KEY_BELONGS_TO)) {
     if (ds->belongsTo) {
       entryDict->put(KEY_BELONGS_TO, GroupId::toHex(ds->belongsTo));
@@ -1581,10 +1592,14 @@ void changeGlobalOption(const Option& option, DownloadEngine* e)
         option.getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT));
   }
   if (option.defined(PREF_MAX_CONCURRENT_DOWNLOADS)) {
-    e->getRequestGroupMan()->setMaxSimultaneousDownloads(
+    e->getRequestGroupMan()->setMaxConcurrentDownloads(
         option.getAsInt(PREF_MAX_CONCURRENT_DOWNLOADS));
     e->getRequestGroupMan()->requestQueueCheck();
   }
+  if (option.defined(PREF_OPTIMIZE_CONCURRENT_DOWNLOADS)) {
+    e->getRequestGroupMan()->setupOptimizeConcurrentDownloads();
+    e->getRequestGroupMan()->requestQueueCheck();
+  }
   if (option.defined(PREF_MAX_DOWNLOAD_RESULT)) {
     e->getRequestGroupMan()->setMaxDownloadResult(
         option.getAsInt(PREF_MAX_DOWNLOAD_RESULT));
